Counter

Struct Counter 

pub struct Counter { /* private fields */ }
A thread-safe diagnostic handle representing a self-declared kernel counter.

This structure contains a pointer to the counter’s static Descriptor layout in memory, and delegates increment, minimum, and maximum operations to highly optimized C++ FFI handlers with zero runtime overhead under ThinLTO.

Implementations

Source

impl Counter

pub const unsafe fn new_with_ptr(descriptor: *const Descriptor) -> Self

Create a new Counter handle using the direct descriptor pointer address.

Safety

This should only be called with a pointer to a valid, linker-defined static descriptor variable.

pub fn add(&self, delta: i64)

Add the given delta value to the calling CPU’s counter slot.

pub fn min(&self, value: i64)

Update the calling CPU’s counter slot to the minimum of its current value and the given value.

pub fn max(&self, value: i64)

Update the calling CPU’s counter slot to the maximum of its current value and the given value.