#[repr(u64)]pub enum Type {
Padding = 0,
Sum = 1,
Min = 2,
Max = 3,
}Expand description
The aggregation type of a kernel counter.
This specifies how the diagnostic tools should combine the per-CPU slot values of the counter to produce a single diagnostic value.
Variants
Padding = 0
Padding element (unused).
Sum = 1
Standard summation counter (aggregates the sum across all CPUs).
Min = 2
Minimum tracker counter (finds the minimum value across all CPUs).
Max = 3
Maximum tracker counter (finds the maximum value across all CPUs).