pub struct Counter { /* private fields */ }Expand description
A thread-safe diagnostic handle representing a self-declared kernel counter.
This structure contains a pointer to the counter’s static Descriptor layout in memory,
and delegates increment, minimum, and maximum operations to highly optimized C++ FFI
handlers with zero runtime overhead under ThinLTO.
Implementations
Sourceimpl Counter
impl Counter
Sourcepub const unsafe fn new_with_ptr(descriptor: *const Descriptor) -> Self
pub const unsafe fn new_with_ptr(descriptor: *const Descriptor) -> Self
Create a new Counter handle using the direct descriptor pointer address.
Safety
This should only be called with a pointer to a valid, linker-defined static descriptor variable.